==> tuia-news-center-api-0.0.73-xt1-20181025.121110-1-sources.jar: cn/com/duiba/tuia/news/center/dto/ownpage/OwnPageItemDto.java <==
package cn.com.duiba.tuia.news.center.dto.ownpage;


import java.io.Serializable;

/**
 * Created by zhou_wb on 2018/9/20.
 */
public class OwnPageItemDto implements Serializable {


    private static final long serialVersionUID = -1366542190992063685L;
    /**
     * tag图标
     */
    private String tagImg;

    /**
     * tag名称
     */
    private String tagName;


    /**
     * tag唯一标识
     */
    private String uniqueIdent;


    /**
     * 跳转路径
     */
    private String routeUrl;


    /**
     * 提示文本
     */
    private String hintText;

    /**
     *气泡文案
     */
    private String bubbleText;

    /**
     * APP URL Scheme，暂用于iOS下载类直投广告屏蔽，需配合活跃拉升判断
     */
    private String scheme;

    /**
     * 活跃拉伸 0：关闭 1:开启
     */
    private Integer  enableActive;

    /**
     * 包名 Android下载类直投广告屏蔽，需配合活跃拉升判断
     */
    private String packageName;


    /**
     * 是否显示红点 0 不显示 1：显示
     */
    private Integer redPoint;

    /**
     * item类型 0：非推啊广告 1:推啊广告
     */
    private Integer type;

    /**
     * 额外字段,配合唯一标识使用，用于支持定制业务场景的参数扩展
     */
    private String extra;

    /**
     * 是否需要登录 0:否 1:是
     */
    private Integer needLogin;



    public String getTagImg() {
        return tagImg;
    }

    public void setTagImg(String tagImg) {
        this.tagImg = tagImg;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public String getRouteUrl() {
        return routeUrl;
    }

    public void setRouteUrl(String routeUrl) {
        this.routeUrl = routeUrl;
    }

    public String getHintText() {
        return hintText;
    }

    public void setHintText(String hintText) {
        this.hintText = hintText;
    }

    public String getBubbleText() {
        return bubbleText;
    }

    public void setBubbleText(String bubbleText) {
        this.bubbleText = bubbleText;
    }

    public String getScheme() {
        return scheme;
    }

    public void setScheme(String scheme) {
        this.scheme = scheme;
    }

    public Integer getEnableActive() {
        return enableActive;
    }

    public void setEnableActive(Integer enableActive) {
        this.enableActive = enableActive;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Integer getRedPoint() {
        return redPoint;
    }

    public void setRedPoint(Integer redPoint) {
        this.redPoint = redPoint;
    }

    public String getUniqueIdent() {
        return uniqueIdent;
    }

    public void setUniqueIdent(String uniqueIdent) {
        this.uniqueIdent = uniqueIdent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getNeedLogin() {
        return needLogin;
    }

    public void setNeedLogin(Integer needLogin) {
        this.needLogin = needLogin;
    }
}

==> tuia-news-center-api-1.6.6.0-xt21-20181204.091427-3-sources.jar: cn/com/duiba/tuia/news/center/dto/ownpage/OwnPageItemDto.java <==
package cn.com.duiba.tuia.news.center.dto.ownpage;


import java.io.Serializable;

/**
 * Created by zhou_wb on 2018/9/20.
 */
public class OwnPageItemDto implements Serializable {


    private static final long serialVersionUID = -1366542190992063685L;
    /**
     * tag图标
     */
    private String tagImg;

    /**
     * tag名称
     */
    private String tagName;


    /**
     * tag唯一标识
     */
    private String uniqueIdent;


    /**
     * 跳转路径
     */
    private String routeUrl;


    /**
     * 提示文本
     */
    private String hintText;

    /**
     *气泡文案
     */
    private String bubbleText;

    /**
     * APP URL Scheme，暂用于iOS下载类直投广告屏蔽，需配合活跃拉升判断
     */
    private String scheme;

    /**
     * 活跃拉伸 0：关闭 1:开启
     */
    private Integer  enableActive;

    /**
     * 包名 Android下载类直投广告屏蔽，需配合活跃拉升判断
     */
    private String packageName;


    /**
     * 是否显示红点 0 不显示 1：显示
     */
    private Integer redPoint;

    /**
     * item类型 0：非推啊广告 1:推啊广告
     */
    private Integer type;

    /**
     * 额外字段,配合唯一标识使用，用于支持定制业务场景的参数扩展
     */
    private String extra;

    /**
     * 是否需要登录 0:否 1:是
     */
    private Integer needLogin;

    /**
     * 新的提示文案
     */
    private String newHintText;

    /**
     * 新的标签图片
     */
    private String newTagImg;



    public String getTagImg() {
        return tagImg;
    }

    public void setTagImg(String tagImg) {
        this.tagImg = tagImg;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public String getRouteUrl() {
        return routeUrl;
    }

    public void setRouteUrl(String routeUrl) {
        this.routeUrl = routeUrl;
    }

    public String getHintText() {
        return hintText;
    }

    public void setHintText(String hintText) {
        this.hintText = hintText;
    }

    public String getBubbleText() {
        return bubbleText;
    }

    public void setBubbleText(String bubbleText) {
        this.bubbleText = bubbleText;
    }

    public String getScheme() {
        return scheme;
    }

    public void setScheme(String scheme) {
        this.scheme = scheme;
    }

    public Integer getEnableActive() {
        return enableActive;
    }

    public void setEnableActive(Integer enableActive) {
        this.enableActive = enableActive;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Integer getRedPoint() {
        return redPoint;
    }

    public void setRedPoint(Integer redPoint) {
        this.redPoint = redPoint;
    }

    public String getUniqueIdent() {
        return uniqueIdent;
    }

    public void setUniqueIdent(String uniqueIdent) {
        this.uniqueIdent = uniqueIdent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getNeedLogin() {
        return needLogin;
    }

    public void setNeedLogin(Integer needLogin) {
        this.needLogin = needLogin;
    }

    public String getNewHintText() {
        return newHintText;
    }

    public void setNewHintText(String newHintText) {
        this.newHintText = newHintText;
    }

    public String getNewTagImg() {
        return newTagImg;
    }

    public void setNewTagImg(String newTagImg) {
        this.newTagImg = newTagImg;
    }
}
